#!/bin/sh
# Script to create a chroot jail for named.

if [ -f /etc/sysconfig/named ]; then
  . /etc/sysconfig/named
else
  echo -n "Could not find sysconfig file"
  failure "Could not find sysconfig file"
  echo
  exit 1
fi

# Making the actual jail structure:
mkdir -p ${JAIL_BASE}/dev
mkdir -p ${JAIL_BASE}/var/run
mkdir -p ${JAIL_BASE}/etc/named.d/{master,slave}
# Copying the needed files:
cp -a /etc/named.conf ${JAIL_BASE}/etc/
# Not sure this should really be there
cp -a /etc/rndc.key ${JAIL_BASE}/etc/
cp -a /etc/named.d/* ${JAIL_BASE}/etc/named.d/
# Making named able to store slave-updates:
chown -R ${NAMEDUSER:-named}.${NAMEDGROUP:-named} ${JAIL_BASE}/etc/named.d/{master,slave}
# Making named able to create pid-file:
chown ${NAMEDUSER:-named}.${NAMEDGROUP:-named} ${JAIL_BASE}/var/run
# The log device:
#mkdir -p ${JAIL_BASE}/dev/log
mount --bind /var/spool/sysklog.d/dev ${JAIL_BASE}/dev
# A devices you really need:
mknod ${JAIL_BASE}/dev/null c 1 3
mknod ${JAIL_BASE}/dev/random c 1 8
# To be able to create correct logs:
cp /etc/localtime ${JAIL_BASE}/etc/
# Tightening permissions:
chown root ${CHROOT_BASE}
chmod 700 ${CHROOT_BASE}
chown ${NAMEDUSER:-named}.${NAMEDGROUP:-named} ${JAIL_BASE}
chmod 700 ${JAIL_BASE}
# Making time immutable:
cd ${JAIL_BASE}
chattr +i etc etc/localtime var
cd -
# That should be it.

